// Copyright 2015, 2016, 2017 Ingo Steinwart
//
// This file is part of liquidSVM.
//
// liquidSVM is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as 
// published by the Free Software Foundation, either version 3 of the 
// License, or (at your option) any later version.
//
// liquidSVM is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.

// You should have received a copy of the GNU Affero General Public License
// along with liquidSVM. If not, see <http://www.gnu.org/licenses/>.


#if !defined (HISTOGRAM_H)
	#define HISTOGRAM_H
	

#include "sources/shared/system_support/compiler_specifics.h"
#include "../../shared/basic_types/dataset_info.h"




#ifdef USE_TR1_CODE
	#include <tr1/unordered_map>
	using namespace std::tr1; 
#else
	#include <unordered_map>
#endif
	
	
typedef string hashkey_type;
enum HISTOGRAM_LABEL_AGGREGATION_TYPES {CELL_HITS_HISTO, AVERAGE_LABEL_SUM_HISTO, LABEL_SUM_HISTO, HISTOGRAM_LABEL_AGGREGATION_TYPES_MAX};


	
//**********************************************************************************************************************************


class Thistogram
{
	public:
		Thistogram();
		~Thistogram();
		
		void clear();
		void reserve(const Tdataset_info& dataset_info, double cell_width);
		void assign(const Tdataset& dataset, double& build_time);
		
		void get_mid_point_dataset(Tdataset& mp_dataset);
		vector <double> predict_labels(const Tdataset& dataset, unsigned label_aggregation_method);
		double get_number_of_cells() const;
		
		
	private:
		int get_bin_number(double value, double min_value, double max_value, unsigned number_of_bins);
		double get_bin_mid_point(unsigned bin_number, double min_value);
		hashkey_type get_key(Tsample* sample);
		
		
		Tdataset_info dataset_info;
		
		unsigned dim;
		double cell_width;
		vector <unsigned> number_of_bins;
		vector <double> bin_minima;
		vector <double> bin_maxima;
		unordered_map <hashkey_type, unsigned> density_histogram;
		unordered_map <hashkey_type, double> label_sum_histogram;
};


//**********************************************************************************************************************************

	
#endif